@@ -3,7 +3,7 @@ http://github.com/tiddlyweb/chrjs/raw/master/main.js
 ***/
 //{{{
 // TiddlyWeb adaptor
-// v0.10.5
+// v0.10.6
 //
 // TODO:
 // * ensure all routes are supported
@@ -267,9 +267,14 @@ $.extend(tiddlyweb.Tiddler.prototype, {
 		if(options.type == "PUT") {
 			var callback = options.success;
 			options.success = function(data, status, xhr) {
+				var loc = xhr.getResponseHeader("Location");
 				var etag = xhr.getResponseHeader("Etag");
-				if(etag) {
+				if(loc && etag) {
 					self.etag = etag;
+					if(!self.bag) {
+						var bag = loc.split("/bags/").pop().split("/")[0];
+						self.bag = new tiddlyweb.Bag(bag, self.recipe.host);
+					}
 					callback(self, status, xhr);
 				} else { // IE
 					self.get(callback, options.error);
@@ -332,7 +337,7 @@ var convertTimestamp = function(t) {
 		parseInt(t.substr(6, 2), 10),
 		parseInt(t.substr(8, 2), 10),
 		parseInt(t.substr(10, 2), 10),
-		parseInt(t.substr(12, 2), 10),
+		parseInt(t.substr(12, 2) || "0", 10),
 		parseInt(t.substr(14, 3) || "0", 10)
 	));
 };
